#
# spec file for package ghc-config-ini
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name config-ini
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.2.7.0
Release:        2.10
Summary:        A library for simple INI-based configuration files
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/1.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-megaparsec-devel
BuildRequires:  ghc-megaparsec-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-unordered-containers-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-directory-prof
BuildRequires:  ghc-hedgehog-devel
BuildRequires:  ghc-hedgehog-prof
BuildRequires:  ghc-ini-devel
BuildRequires:  ghc-ini-prof
%endif

%description
The 'config-ini' library is a set of small monadic languages for writing simple
configuration languages with convenient, human-readable error messages.

> parseConfig :: IniParser (Text, Int, Bool) > parseConfig = section "NETWORK"
$ do > user <- field "user" > port <- fieldOf "port" number > enc <-
fieldFlagDef "encryption" True > return (user, port, enc).

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Wed Mar 27 2024 Peter Simons <psimons@suse.com>
- Update config-ini to version 0.2.7.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sun Nov  5 2023 Peter Simons <psimons@suse.com>
- Update config-ini to version 0.2.7.0.
  Upstream has not updated the file "CHANGELOG.md" since the last
  release.
* Thu Jun 22 2023 Peter Simons <psimons@suse.com>
- Update config-ini to version 0.2.6.0.
  Upstream has not updated the file "CHANGELOG.md" since the last
  release.
* Fri Apr 14 2023 Peter Simons <psimons@suse.com>
- Update config-ini to version 0.2.5.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Mon Sep 19 2022 Peter Simons <psimons@suse.com>
- Update config-ini to version 0.2.5.0.
  Upstream has not updated the file "CHANGELOG.md" since the last
  release.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Wed Sep 30 2020 psimons@suse.com
- Update config-ini to version 0.2.4.0 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Wed Sep  9 2020 Peter Simons <psimons@suse.com>
- Relax over-specified constraint on megaparsec.
* Mon Aug 31 2020 psimons@suse.com
- Update config-ini to version 0.2.4.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun  9 2020 psimons@suse.com
- Add config-ini at version 0.2.4.0.
